package com.ruoyi.learn.service;

import java.util.List;
import com.ruoyi.learn.domain.LearnTestStudent;

/**
 * 测试学生Service接口
 * 
 * @author ruoyi
 * @date 2025-09-18
 */
public interface ILearnTestStudentService 
{
    /**
     * 查询测试学生
     * 
     * @param id 测试学生主键
     * @return 测试学生
     */
    public LearnTestStudent selectLearnTestStudentById(Long id);

    /**
     * 查询测试学生列表
     * 
     * @param learnTestStudent 测试学生
     * @return 测试学生集合
     */
    public List<LearnTestStudent> selectLearnTestStudentList(LearnTestStudent learnTestStudent);

    /**
     * 新增测试学生
     * 
     * @param learnTestStudent 测试学生
     * @return 结果
     */
    public int insertLearnTestStudent(LearnTestStudent learnTestStudent);

    /**
     * 修改测试学生
     * 
     * @param learnTestStudent 测试学生
     * @return 结果
     */
    public int updateLearnTestStudent(LearnTestStudent learnTestStudent);

    /**
     * 批量删除测试学生
     * 
     * @param ids 需要删除的测试学生主键集合
     * @return 结果
     */
    public int deleteLearnTestStudentByIds(Long[] ids);

    /**
     * 删除测试学生信息
     * 
     * @param id 测试学生主键
     * @return 结果
     */
    public int deleteLearnTestStudentById(Long id);
}
